Mover
=====

.. autoexception:: sokoenginepy.game.IllegalMoveError

.. autoexception:: sokoenginepy.game.NonPlayableBoardError


Direction
---------

.. autoclass:: sokoenginepy.game.Direction
    :members:
    :undoc-members:


SolvingMode
-----------

.. autoclass:: sokoenginepy.game.SolvingMode
    :members:
    :undoc-members:


Mover
-----

.. autoclass:: sokoenginepy.game.Mover
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    :member-order: bysource


PusherStep
----------

.. autoclass:: sokoenginepy.game.PusherStep
    :members:
    :undoc-members:
